===============================================================================================================
``gordon-introspection``: Introspection Server Plugin for Gordon: Event-Driven Cloud DNS registration
===============================================================================================================


.. include:: ../README.rst
   :start-after: desc-begin
   :end-before: desc-end


Release v\ |release| (:doc:`What's new? <changelog>`).

.. warning::

    This is still in the planning phase and under active development. Gordon and this plugin should not be used in production, yet.

.. include:: ../README.rst
   :start-after: intro-begin


User Guide
==========

.. toctree::
   :maxdepth: 1

   config
   endpoints


Project Information
===================

.. toctree::
   :maxdepth: 1

   license
   contributing
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
